/* |----------------------- COMMON STYLE RULES --------------------------------------------------------------------> */

.jp-ReactWidget {
  color: var(--jp-ui-font-color1);
  background: var(--jp-layout-color1);
}

.jp-dataviz{
  margin-top: -8px;
  min-width: 650px !important;
}

.marginsNotebook {
  padding-right: 5px;
  padding-left: 70px;
}

/* Any element that fills its parent by width */
.full-width {
  width: 100%;
}

/* Any element that fills its parent by height */
.full-height-container {
  height: 100%;
}

/* Any element that needs margin */
.margin-right {
  margin-right: 10px;
}

/* Any short element */
.short {
  height: 26px !important;
  padding: 0 12px !important;
}

/* Any centered element */
.centered {
  display: flex;
  justify-content: center;
  align-items: center;
}

/* Make element visible and flexible */
.show_flex {
  display: flex !important;
}

/* Add ellipsis */
.ellipsized {
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
}

/* <---------------------------------------------------------------------------------------------------------------| */

/* |----------------------- FORMULABAR: GENERAL STYLING -----------------------------------------------------------> */

.formulaFormDivider{
  border-bottom: 1px solid black;
  width: 100%;
  border-color: #B2B2B2;
  margin-bottom: 10px;
}

#root__title{
  border-bottom-width: 0px;
  margin-bottom: 5px;
}

/* <---------------------------------------------------------------------------------------------------------------| */

/* |----------------------- FORMULABAR: SIDE-BY-SIDE FIELDS RULES -------------------------------------------------> */

.content {
  min-height: 400px;
  align-items: center;
  padding-top: 20px;
  padding-bottom: 10px;
  padding-right: 20px;
  padding-left: 20px;
  overflow: auto;
}

/* Side-by-side container */
.side-by-side-fields > fieldset {
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  width: 100%;
  margin-bottom: 10px;
  position: relative;
}

/* Left and right fields of side-by-side container */
.side-by-side-fields .left-field,
.side-by-side-fields .right-field {
  width: 49%;
}

/* Rewrite left field rules for data-transformation-form */
.data-transformation-form .left-field {
  width: 33%;
}

/* Rewrite right field rules for data-transformation-form */
.data-transformation-form .right-field {
  width: 66%;
}

/* Rules for description inside of side-by-side container */
.side-by-side-fields .field-description {
  width: 100%;
  margin-bottom: 10px;
}
/* <---------------------------------------------------------------------------------------------------------------| */


/* |----------------------- FORMULABAR: REWRITE ITEMS AT ARRAY LEVEL OF TRANSFORMATIONS.JSON ----------------------> */

/* Item container */
.array-item {
  display: flex;
  align-items: center;
}

/* Item buttons */
.array-item-toolbox {
  margin-bottom: 9px;
}
/* <---------------------------------------------------------------------------------------------------------------| */


/* |----------------------- REWRITE QUERY BUILDER STYLE RULES -----------------------------------------------------> */

#query-form .group--conjunctions label{
  margin-right: 10px;
}

#query-form .group--conjunctions input{
  margin-right: 2px;
}

#query-form .group{
  background-color: #ffffff;
  border: 2px solid #cccccc;
}

#query-form .group-or-rule-container {
  padding-right: 0;
}

#query-form .query-builder {
  margin: 0;
}

#query-form .query-builder-container {
  padding: 10px 0;
  margin-bottom: 20px;
}

.query-builder-container button {
  color: #333333;
  background-color: #ffffff;
  border-color: #a6a6a6;
  display: inline-block;
  cursor: pointer;
  padding: 2px 9px;
  font-size: 14px;
  line-height: 1.42857143;
  border-radius: 4px;
}

/* Style for add rule/add group buttons to make tab navigation easier */
.query-builder-container button:focus {
  border-color: #2684FF;
  border-width: 3px;
}

/* Make action buttons always visible */
.group--actions.group--actions--tr {
  opacity: 1 !important;
}

/* Style for action buttons */
.group--actions.group--actions--tr > button {
  margin-right: 5px;
}

.group--actions.group--actions--tr > button:last-child {
  margin-right: 0;
}

#query-form .rule {
  background-color: #f7f7f7;
  margin-right: 5px;
}

.rule--header > button,
.group--actions.group--actions--tr > button:nth-child(3) {
  background: #f7f7f7;
  opacity: 1 !important;
}

/* Styles for rule fields */
.rule--field,
.rule--value,
.rule--operator {
  width: 30%;
}
.rule--operator {
  max-width: 130px;
}

.rule--body {
  display: flex;
}

.rule--value input {
  height: 100%;
  padding: 6px 12px;
  font-size: 14px;
  border: 1px solid #ccc;
  border-radius: 4px;
  width: 100%;
}

/* -------------> Rewrite existing rules for widgets */
.rule--widget--MULTISELECT,
.rule--widget--MULTISELECT .widget--widget {
  width: 100%;
}
.rule--widget--NUMBER,
.rule--widget--NUMBER .widget--widget,
.rule--widget--TEXT,
.rule--widget--TEXT .widget--widget{
  height: 100%;
  width: 100%;
}
/* Set specific width for external block */
.rule--widget--BOOLEAN {
  max-width: 70%;
  width: 170px;
  height: 100%;
}

/* Make inner block flex to align elements inside of it */
.rule--widget--BOOLEAN .widget--widget {
  display: flex;
  align-items: center;
  height: 100%;
}

/* Remove unnecessary margin from radio button */
.rule--widget--BOOLEAN .widget--widget input[type="radio"] {
  margin-left: 10px;
  height: 20px;
  width: 20px;
}

.rule--widget--BOOLEAN .widget--widget label{
  height: 20px;
  margin-top: 10px;
  margin-left: 5px
}
/* <------------------------------------------------- */
/* <---------------------------------------------------------------------------------------------------------------| */


/* |----------------------- DATA VISUALIZER RULES -----------------------------------------------------------------> */

/* |----------- Binder button --------------------------------------->*/

.binderButtonSeparator{
  margin-bottom: 10px;
}

.binderButton{
  background-color: #000000;
  color: #FFFFFF;
  border-radius: 1rem;
  border: 0;
  padding-top: 5px;
  padding-bottom: 5px;
  padding-left: 15px;
  padding-right: 15px;
  height: 22px;
}

.binderButton:hover{
  color: #FFFFFF;
  background-color: #5249BA !important;
  text-decoration: none;
}

/* <--------------------------------------------------------------|*/

/* |----------- Navigation --------------------------------------->*/
/* Navigation bar */
.scroll-nav {
  overflow-x: auto;
  overflow-y: hidden;
  white-space: nowrap;
  position: relative;
  z-index: 5;
}

/* Navigation tab (button) */
.tab-button {
  min-width: 77px;
  height: 30px;
  background: #FFFFFF;
  border: 1px solid #DDDDDD;
  border-right: 0;
  box-sizing: border-box;
  border-radius: 4px 0 0 0;
  font-size: 14px;
  line-height: 21px;
  display: inline-block;
  transition: 0.2s ease;
}

/* Navigation tab (button) style by hover */
.tab-button:hover,
.dropdown-button:hover
{
  background-color: #EEEEEE;
}

/* Navigation tab (button) style if active */
.tab-button_active {
  background-color: #ffffff;
  color: #353EFF !important;
}

/* Navigation tab (button) style if inactive */
.tab-button_inactive {
  color: #959494;
  background-color: #f6f6f6;
}

/* Containers for dropdown button */
.dropdown-container {
  display: flex;
}

.dropdown {
  display: flex;
  min-width: 97px;
}

/* Dropdown button container */
.dropdown-button {
  height: 30px;
  padding: 2px 4px;
  margin-right: 3px;
  border: 1px solid #DDDDDD;
  border-left: 0;
  border-radius: 0 4px 0 0;
  display: flex;
  align-items: center;
  justify-content: center;
}

/* Rewrite bootstrap's dropdown menu */
.dropdown-menu {
  padding: 0 !important;
  margin: 0 !important;
  border-top-left-radius: 0 !important;
  border-top-right-radius: 0 !important;
}

/* Rewrite bootstrap's dropdown menu item */
.dropdown-item {
  display: block;
  padding: 2px 10px;
  color: #212529;
  width: max-content;
  text-decoration: none;
}

.dropdown-item:hover {
  background-color: #f3f3f3;
  text-decoration: none;
  color: #212529;
}

/* CSS arrow for dropdown container */
.dropdown-arrow {
  height: 0;
  width: 0;
  border-top: .3em solid;
  border-right: .3em solid transparent;
  border-bottom: 0;
  border-left: .3em solid transparent;
}

/* Rules for variables button */
.variables-button {
  margin-right: 4px;
  border: 1px solid #CDDCA8;
  border-top-right-radius: 4px;
  background-color: #f6f6f6;
  color: #959494;
}

.variables-button:hover {
  background-color: #EEEEEE;
}
/* <--------------------------------------------------------------|*/

/* Container for table */
.tab-item {
  width: fit-content;
  max-width: 100%;
  overflow: auto;
  border: 1px solid #ddd;
  height: calc(100vh - 137px);
}

.disclaimer {
  font-size: 12px;
  color: #2d2d2d;
  padding: 8px;
  margin: 0;
}

/* ---> Table rules ------------------------------------------- */

/* Table style */
.div-table {
  width: 100%;
  border-collapse: collapse;
  display: table;
  border-color: grey;
  border-spacing: 2px;
}

/* Dark header style */
.thead-dark {
  background-color: #212529;
  color: #ffffff;
}

/* Add padding to all .th children*/
.th > *{
  padding: .35rem;
}

.header {
  position: relative;
}

.header:hover > .dropdown-header-button {
  right: 0;
}

/* Dropdown button for column headers*/
.dropdown-header-button {
  border: 1px solid #949494;
  transition: right 0.3s ease;
  position: absolute;
  width: 34px;
  max-width: 100%;
  right: -34px;
  top: 0;
  height: 90%;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 4px 0 0 4px;
  background-color: #969696;
}

.dropdown-header-button:hover {
  cursor: pointer;
}

/* Header for dropdown menu */
.sort-header {
  color: #888888;
  padding: 0 0 0 10px;
  margin: 0;
}

/* Dropdown menu for column headers */
.dropdown-header-menu {
  padding: 10px;
  border-radius: 5px;
  position: absolute;
  left: 0;
  top: 50%;
  z-index: 5;
  background-color: #e3e3e3;
  display: none;
}

/* Position of sort arrow */
.sort-arrow {
  position: absolute;
  right: 10%;
  top: 0;
  color: white;
  display: none;
}

/* Add different style to index column */
.index-column-header {
  background-color: #585757;
}

/* Style for data type info */
.data-type-info {
  color: grey;
  width: 100%;
  font-size: 11px;
  z-index: 1;
  position: relative;
}

/* Cell's style */
.td{
  padding: .75rem;
  font-size: 12px;
}

/* Striped table style */
.div-table-striped .tbody .tr:nth-of-type(odd) {
  background-color: rgba(0,0,0,.05);
}

/* Sticky position for header */
.sticky {
  position: sticky;
  top: 0;
}

.th, .td {
  cursor: text;
}

.tr {
  width: 100% !important;
  border-top: 1px solid #dee2e6;
  align-items: center;
}

.trash-bin-button {
  border: none;
  background-color: transparent;
}

/* White row for data types background */
.header-white-row {
  background-color: white;
  width: 100%;
  height: 25px;
  display: flex;
  position: absolute;
  bottom: 0;
  left: 0;
  align-items: center;
  z-index: 1;
  border-bottom: 1px solid grey;
}

.delimiter-wrapper {
  background-color: transparent;
  width: 8px;
  position: absolute;
  top: 0;
  right: -3px;
  padding: 0;
  height: 100%;
  z-index: 5;
}

.delimiter {
  width: 1px;
  height: 100%;
  background-color: rgba(128, 128, 128, 0.2);
  position: absolute;
  right: 20%;
}

.delimiter:hover {
  cursor: col-resize;
}

/* <------------------------- */

/* <----------------------------------------------------------- */

/* <---------------------------------------------------------------------------------------------------------------| */

/* |---------------------------------------- PAGINATION PANEL -----------------------------------------------------> */

.pagination-panel {
  display: flex;
  border-radius: 3px;
  flex-wrap: wrap;
  font-size: 12px;
}

.pagination-segment {
  padding: 5px 12px;
  border: 1px solid hsl(0, 0%, 80%);
  min-width: 50px;
  border-radius: 0;
  transition: all 0.3s ease;
  display: flex;
  align-items: center;
  justify-content: center;
}

.pagination-page-select {
  width: 160px;
}

.pagination-size-select {
  width: 130px;
}

.pagination-segment:first-child {
  border-radius: 3px 0 0 3px;
}

.pagination-segment:last-child {
  border-radius: 0 3px 3px 0;
}

button.pagination-segment {
  background-color: white;
  color: black;
}

button.pagination-segment:disabled {
  background-color: #dedede;
  color: #797979;
}

button.pagination-segment:active {
  background-color: silver;
}

/* <---------------------------------------------------------------------------------------------------------------| */

/* |-------------------------------- FEEDBACK BUTTONS STYLE RULES -------------------------------------------------> */

.BinaryFeedback__container,
.BinaryFeedback__actions {
  width: 100%;
}

.BinaryFeedback__positive,
.BinaryFeedback__negative {
  width: 50%;
  border-color: #cccccc !important;
  justify-content: flex-start !important;
  padding: 2px 10px !important;
  min-height: 26px;
}

.BinaryFeedback__positive {
  border-radius: 5px 0 0 5px !important;
}
.BinaryFeedback__negative {
  border-radius: 0 5px 5px 0 !important;
}

.BinaryFeedback__negative:hover p,
.BinaryFeedback__positive:hover p,
.BinaryFeedback__selected p,
.BinaryFeedback__disabled p{
  color: white !important;
}

#feedback {
  display: flex;
  flex-wrap: wrap;
  width: 100%;
  justify-content: space-between;
}

#feedback__negative-description {
  display: none;
  width: 66%;
  min-width: 310px;
}

#feedback__buttons {
  width: 33%;
  min-width: 230px;
}

.feedback__content {
  display: flex;
  justify-content: center;
  align-items: center;
  overflow: hidden;
  width: 100%;
}

.feedback__buttons-text {
  margin: 0 0 0 5px;
  white-space: nowrap;
}
/* <---------------------------------------------------------------------------------------------------------------| */
/* |--------------------------------- STYLES FOR SVG ICONS --------------------------------------------------------> */
.svg-magnifier {
  width: 100%;
  height: 100%;
}

.svg-magnifier path,
.svg-magnifier polygon,
.svg-magnifier rect {
  fill: #4691f6;
}

.svg-magnifier circle {
  stroke: #4691f6;
  stroke-width: 1;
}

.svg-bin path,
.svg-bin polygon,
.svg-bin rect {
  fill: red;
}

/* <---------------------------------------------------------------------------------------------------------------| */
/* |------------------------------- CHAT WIDGET STYLE -------------------------------------------------------------> */

/* Rewrite native style */
.Papercups-toggleButtonContainer,
.Papercups-chatWindowContainer {
  position: absolute !important;
}
/* <---------------------------------------------------------------------------------------------------------------| */

/* |------------------------------- RADIO BUTTON GROUP STYLE ------------------------------------------------------> */

/* Container for radio buttons */
.radio-button-group {
  position: relative;
  width: 100%;
  display: inline-flex;
  vertical-align: middle;
}

.radio-wrapper {
  min-width: 65px;
}

/* Hide default radio button */
.radio-button {
  position: absolute;
  clip: rect(0,0,0,0);
  pointer-events: none;
}

/* Label is the wrapper of radio */
.radio-button-label {
  color: #0d6efd;
  border: 1px solid #0d6efd;
  padding: 6px 12px;
  cursor: pointer;
  transition: all 0.7s ease;
  width: 100%;
}

/* Set special borders for first and last buttons */
.radio-button-group > div:first-child > .radio-button-label {
  border-top-left-radius: 5px;
  border-bottom-left-radius: 5px;
}

.radio-button-group > div:last-child .radio-button-label {
  border-top-right-radius: 5px;
  border-bottom-right-radius: 5px;
}

/* Change colors radio is checked */
.radio-button:checked+.radio-button-label {
  color: #fff;
  background-color: #0d6efd;
  border-color: #0d6efd;
}
/* <---------------------------------------------------------------------------------------------------------------| */
/* |------------------------------- EMPTY STATE COMPONENT STYLE ---------------------------------------------------> */
.empty-state__container {
  height: 100%;
  width: 100%;
  display: flex;
  flex-flow: column;
  justify-content: center;
  align-items: center;
}

.empty-state__title {
  font-style: normal;
  font-weight: bold;
  font-size: 34px;
  color: #858585;
}

.empty-state__link {
  font-style: normal;
  font-weight: bold;
  font-size: 14px;
  color: #109CF1;
}
/* <---------------------------------------------------------------------------------------------------------------| */
/* |------------------------------- RELOAD BUTTON STYLE -----------------------------------------------------------> */
.reload-button__container {
  display: flex;
  align-items: center;
  justify-content: space-between;
}

.reload-button__container:active *{
  color: #a4d1f8;
}

.reload-button__container > button {
  border: none;
  background-color: transparent;
}

.reload-button__container > label{
  font-style: normal;
  font-weight: bold;
  font-size: 12px;
  color: #109CF1;
  cursor: pointer;
}

.reload-button__container:hover > * {
  color: #23527c;
  text-decoration: underline;
}
/* <---------------------------------------------------------------------------------------------------------------| */
/* |------------------------------------- SPINNER STYLE -----------------------------------------------------------> */
.spinner-wrapper {
  position: fixed;
  top: 28px;
  left: 0;
  width: 100%;
}

.spinner-wrapper > * {
  position: inherit !important;
}
/* <---------------------------------------------------------------------------------------------------------------| */
/* |------------------------------- RESTYLING OF APP -----------------------------------------------------------> */

/* Lines on the top of the widget window removed for more stylized look*/
:not(.jp-NotebookPanel) > .jp-Toolbar {
  border-bottom: none;
  box-shadow: none;
}

/* Top left logo */
#jp-MainLogo {
  margin-left: 3px;
  width: 26px;
  background-image: url(logo.png)
}

#jp-MainLogo > svg {
    visibility: hidden;
}

/* <---------------------------------------------------------------------------------------------------------------| */
/* |------------------------------- CELL FORMULABAR -----------------------------------------------------------> */


.jp-InputArea-editor{
  background: #F7F7F7;
  border: none;
}
